@@ -63,7 +63,8 @@ const (
 	KuryrConfigMapName                     = "kuryr-config"
 	DNSNamespace                           = "openshift-dns"
 	DNSServiceName                         = "dns-default"
-	etcdPort                               = 2379
+	etcdClientPort                         = 2379
+	etcdServerToServerPort                 = 2380
 	dnsPort                                = 53
 	apiPort                                = 6443
 	routerMetricsPort                      = 1936
@@ -1103,18 +1104,25 @@ func BootstrapKuryr(conf *operv1.NetworkSpec, kubeClient client.Client) (*bootst
 
 	var sgRules = []sgRule{
 		{podSgId, "0.0.0.0/0", 0, 0, rules.ProtocolTCP},
-		{masterSgId, openStackSvcCIDR, etcdPort, etcdPort, rules.ProtocolTCP},
+		{masterSgId, openStackSvcCIDR, etcdClientPort, etcdClientPort, rules.ProtocolTCP},
 		{masterSgId, openStackSvcCIDR, apiPort, apiPort, rules.ProtocolTCP},
+		// NOTE (maysamacedo): Splitting etcd sg port ranges in different
+		// rules to avoid the issue of constant leader election changes
+		{masterSgId, workerSubnet.CIDR, etcdClientPort, etcdClientPort, rules.ProtocolTCP},
+		{masterSgId, workerSubnet.CIDR, etcdServerToServerPort, etcdServerToServerPort, rules.ProtocolTCP},
 	}
 
 	var decommissionedRules = []sgRule{
 		{podSgId, workerSubnet.CIDR, 0, 0, ""},
-		{masterSgId, openStackSvcCIDR, 2379, 2380, rules.ProtocolTCP},
+		{masterSgId, openStackSvcCIDR, etcdClientPort, etcdServerToServerPort, rules.ProtocolTCP},
+		// NOTE(maysamacedo): This sg rule is created by the installer. We need to remove it and
+		// create two more, each with a unique port from the range.
+		{masterSgId, workerSubnet.CIDR, etcdClientPort, etcdServerToServerPort, rules.ProtocolTCP},
 	}
 
 	for _, cidr := range podSubnetCidrs {
 		sgRules = append(sgRules,
-			sgRule{masterSgId, cidr, etcdPort, etcdPort, rules.ProtocolTCP},
+			sgRule{masterSgId, cidr, etcdClientPort, etcdClientPort, rules.ProtocolTCP},
 			sgRule{masterSgId, cidr, dnsPort, dnsPort, rules.ProtocolTCP},
 			sgRule{masterSgId, cidr, dnsPort, dnsPort, rules.ProtocolUDP},
 			sgRule{workerSgId, cidr, dnsPort, dnsPort, rules.ProtocolTCP},
@@ -1220,9 +1228,11 @@ func BootstrapKuryr(conf *operv1.NetworkSpec, kubeClient client.Client) (*bootst
 	log.Print("Creating OpenShift API loadbalancer pool members")
 	r, _ := regexp.Compile(fmt.Sprintf("^%s-(master-port-[0-9]+|bootstrap-port)$", clusterID))
 	portList, err := listOpenStackPortsMatchingPattern(client, tag, r)
+	addresses := make([]string, 0)
 	for _, port := range portList {
 		if len(port.FixedIPs) > 0 {
 			portIp := port.FixedIPs[0].IPAddress
+			addresses = append(addresses, portIp)
 			log.Printf("Found port %s with IP %s", port.ID, portIp)
 
 			// We want bootstrap to stop being used as soon as possible, as it will serve
@@ -1244,6 +1254,11 @@ func BootstrapKuryr(conf *operv1.NetworkSpec, kubeClient client.Client) (*bootst
 		}
 	}
 
+	err = purgeOpenStackLbPoolMember(lbClient, poolId, addresses)
+	if err != nil {
+		return nil, errors.Wrap(err, "Failed on purging invalid LB members from LB pool")
+	}
+
 	log.Print("Ensuring certificates")
 	ca, key, err := ensureCA(kubeClient)
 	if err != nil {
